/*
 * Copyright (c) 2013, 2019 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.jersey.tests.integration.jersey2154;

import javax.ejb.EJBException;
import javax.ejb.Stateless;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Response;

/**
 * EJB bean to reproduce JERSEY-2154. Bellow generated {@link WebApplicationException}
 * should get mapped to response even when wrapped into an {@link EJBException}
 * by the underlying EJB container.
 *
 * @author Jakub Podlesak
 */
@Stateless
public class EjbBean {

    /**
     * This is to make sure the exception thrown gets wrapped with an {@link EJBException}.
     *
     * @return nothing, just throws an exception.
     */
    public String exceptionDrivenResponse() {
        throw new WebApplicationException(Response.ok("If you read this, the exception got mapped successfully!").build());
    }
}
